@@ -1,5 +1,10 @@
-from .utils import (HeatCapacityConstants, NRTLParameters, R,
-                    VaporPressureConstants, VPConstantsType)
+from .utils import (
+    HeatCapacityConstants,
+    NRTLParameters,
+    R,
+    VaporPressureConstants,
+    VPConstantsType,
+)
 
 __all__ = [
     "VaporPressureConstants",
